==> larus_board-0.8.36.tbz: larus_board-0.8.36/setup/data_init.sql <==
INSERT INTO {$PREFIX}acl (a_action, a_use_group, a_key, a_allow) VALUES
('acp_acl_delete', '1', 1, '0'),
('acp_acl_delete', '1', 2, '0'),
('acp_acl_delete', '1', 3, '0'),
('acp_acl_delete', '1', 4, '1'),
('acp_acl_delete', '1', 5, '1'),
('acp_acl_edit', '1', 1, '0'),
('acp_acl_edit', '1', 2, '0'),
('acp_acl_edit', '1', 3, '0'),
('acp_acl_edit', '1', 4, '1'),
('acp_acl_edit', '1', 5, '1'),
('acp_acl_list', '1', 1, '0'),
('acp_acl_list', '1', 2, '0'),
('acp_acl_list', '1', 3, '0'),
('acp_acl_list', '1', 4, '1'),
('acp_acl_list', '1', 5, '1'),
('acp_acl_new', '1', 1, '0'),
('acp_acl_new', '1', 2, '0'),
('acp_acl_new', '1', 3, '0'),
('acp_acl_new', '1', 4, '1'),
('acp_acl_new', '1', 5, '1'),
('acp_cfg_edit', '1', 1, '0'),
('acp_cfg_edit', '1', 2, '0'),
('acp_cfg_edit', '1', 3, '0'),
('acp_cfg_edit', '1', 4, '1'),
('acp_cfg_edit', '1', 5, '1'),
('acp_cfg_list', '1', 1, '0'),
('acp_cfg_list', '1', 2, '0'),
('acp_cfg_list', '1', 3, '0'),
('acp_cfg_list', '1', 4, '1'),
('acp_cfg_list', '1', 5, '1'),
('acp_group_delete', '1', 1, '0'),
('acp_group_delete', '1', 2, '0'),
('acp_group_delete', '1', 3, '0'),
('acp_group_delete', '1', 4, '1'),
('acp_group_delete', '1', 5, '1'),
('acp_group_edit', '1', 1, '0'),
('acp_group_edit', '1', 2, '0'),
('acp_group_edit', '1', 3, '0'),
('acp_group_edit', '1', 4, '1'),
('acp_group_edit', '1', 5, '1'),
('acp_group_list', '1', 1, '0'),
('acp_group_list', '1', 2, '0'),
('acp_group_list', '1', 3, '0'),
('acp_group_list', '1', 4, '1'),
('acp_group_list', '1', 5, '1'),
('acp_group_new', '1', 1, '0'),
('acp_group_new', '1', 2, '0'),
('acp_group_new', '1', 3, '0'),
('acp_group_new', '1', 4, '1'),
('acp_group_new', '1', 5, '1'),
('acp_log', '1', 1, '0'),
('acp_log', '1', 2, '0'),
('acp_log', '1', 3, '0'),
('acp_log', '1', 4, '1'),
('acp_log', '1', 5, '1'),
('acp_overview', '1', 1, '0'),
('acp_overview', '1', 2, '0'),
('acp_overview', '1', 3, '0'),
('acp_overview', '1', 4, '1'),
('acp_overview', '1', 5, '1'),
('acp_pp_delete', '1', 1, '0'),
('acp_pp_delete', '1', 2, '0'),
('acp_pp_delete', '1', 3, '0'),
('acp_pp_delete', '1', 4, '1'),
('acp_pp_delete', '1', 5, '1'),
('acp_pp_edit', '1', 1, '0'),
('acp_pp_edit', '1', 2, '0'),
('acp_pp_edit', '1', 3, '0'),
('acp_pp_edit', '1', 4, '1'),
('acp_pp_edit', '1', 5, '1'),
('acp_pp_list', '1', 1, '0'),
('acp_pp_list', '1', 2, '0'),
('acp_pp_list', '1', 3, '0'),
('acp_pp_list', '1', 4, '1'),
('acp_pp_list', '1', 5, '1'),
('acp_pp_new', '1', 1, '0'),
('acp_pp_new', '1', 2, '0'),
('acp_pp_new', '1', 3, '0'),
('acp_pp_new', '1', 4, '1'),
('acp_pp_new', '1', 5, '1'),
('acp_task_edit', '1', 1, '0'),
('acp_task_edit', '1', 2, '0'),
('acp_task_edit', '1', 3, '0'),
('acp_task_edit', '1', 4, '1'),
('acp_task_edit', '1', 5, '1'),
('acp_task_list', '1', 1, '0'),
('acp_task_list', '1', 2, '0'),
('acp_task_list', '1', 3, '0'),
('acp_task_list', '1', 4, '1'),
('acp_task_list', '1', 5, '1'),
('cachemgr', '1', 1, '0'),
('cachemgr', '1', 2, '0'),
('cachemgr', '1', 3, '1'),
('cachemgr', '1', 4, '1'),
('cachemgr', '1', 5, '1'),
('forgot_password', '1', 1, '1'),
('forgot_password', '1', 2, '0'),
('forgot_password', '1', 3, '0'),
('forgot_password', '1', 4, '0'),
('forgot_password', '1', 5, '0'),
('help', '1', 1, '1'),
('help', '1', 2, '1'),
('help', '1', 3, '1'),
('help', '1', 4, '1'),
('help', '1', 5, '1'),
('login', '1', 1, '1'),
('login', '1', 2, '0'),
('login', '1', 3, '0'),
('login', '1', 4, '0'),
('login', '1', 5, '0'),
('logout', '1', 1, '0'),
('logout', '1', 2, '1'),
('logout', '1', 3, '1'),
('logout', '1', 4, '1'),
('logout', '1', 5, '1'),
('mcp_overview', '1', 1, '0'),
('mcp_overview', '1', 2, '0'),
('mcp_overview', '1', 3, '1'),
('mcp_overview', '1', 4, '0'),
('mcp_overview', '1', 5, '1'),
('mcp_request', '1', 1, '0'),
('mcp_request', '1', 2, '0'),
('mcp_request', '1', 3, '1'),
('mcp_request', '1', 4, '0'),
('mcp_request', '1', 5, '1'),
('member_list', '1', 1, '1'),
('member_list', '1', 2, '1'),
('member_list', '1', 3, '1'),
('member_list', '1', 4, '1'),
('member_list', '1', 5, '1'),
('overview', '1', 1, '1'),
('overview', '1', 2, '1'),
('overview', '1', 3, '1'),
('overview', '1', 4, '1'),
('overview', '1', 5, '1'),
('post_approve', '1', 1, '0'),
('post_approve', '1', 2, '0'),
('post_approve', '1', 3, '1'),
('post_approve', '1', 4, '0'),
('post_approve', '1', 5, '1'),
('post_delete', '1', 1, '0'),
('post_delete', '1', 2, '0'),
('post_delete', '1', 3, '1'),
('post_delete', '1', 4, '0'),
('post_delete', '1', 5, '1'),
('post_edit', '1', 1, '0'),
('post_edit', '1', 2, '1'),
('post_edit', '1', 3, '1'),
('post_edit', '1', 4, '1'),
('post_edit', '1', 5, '1'),
('post_edit_revert', '1', 1, '0'),
('post_edit_revert', '1', 2, '0'),
('post_edit_revert', '1', 3, '1'),
('post_edit_revert', '1', 4, '0'),
('post_edit_revert', '1', 5, '1'),
('post_lock', '1', 1, '0'),
('post_lock', '1', 2, '0'),
('post_lock', '1', 3, '1'),
('post_lock', '1', 4, '0'),
('post_lock', '1', 5, '1'),
('post_rate', '1', 1, '0'),
('post_rate', '1', 2, '1'),
('post_rate', '1', 3, '1'),
('post_rate', '1', 4, '1'),
('post_rate', '1', 5, '1'),
('post_reply', '1', 1, '0'),
('post_reply', '1', 2, '1'),
('post_reply', '1', 3, '1'),
('post_reply', '1', 4, '1'),
('post_reply', '1', 5, '1'),
('post_topic', '1', 1, '0'),
('post_topic', '1', 2, '1'),
('post_topic', '1', 3, '1'),
('post_topic', '1', 4, '1'),
('post_topic', '1', 5, '1'),
('reauth', '1', 1, '0'),
('reauth', '1', 2, '1'),
('reauth', '1', 3, '1'),
('reauth', '1', 4, '1'),
('reauth', '1', 5, '1'),
('register', '1', 1, '1'),
('register', '1', 2, '0'),
('register', '1', 3, '0'),
('register', '1', 4, '0'),
('register', '1', 5, '0'),
('rss', '1', 1, '1'),
('rss', '1', 2, '1'),
('rss', '1', 3, '1'),
('rss', '1', 4, '1'),
('rss', '1', 5, '1'),
('search', '1', 1, '1'),
('search', '1', 2, '1'),
('search', '1', 3, '1'),
('search', '1', 4, '1'),
('search', '1', 5, '1'),
('topic', '1', 1, '1'),
('topic', '1', 2, '1'),
('topic', '1', 3, '1'),
('topic', '1', 4, '1'),
('topic', '1', 5, '1'),
('ucp_blacklist', '1', 1, '0'),
('ucp_blacklist', '1', 2, '1'),
('ucp_blacklist', '1', 3, '1'),
('ucp_blacklist', '1', 4, '1'),
('ucp_blacklist', '1', 5, '1'),
('ucp_bookmark', '1', 1, '0'),
('ucp_bookmark', '1', 2, '1'),
('ucp_bookmark', '1', 3, '1'),
('ucp_bookmark', '1', 4, '1'),
('ucp_bookmark', '1', 5, '1'),
('ucp_profile', '1', 1, '0'),
('ucp_profile', '1', 2, '1'),
('ucp_profile', '1', 3, '1'),
('ucp_profile', '1', 4, '1'),
('ucp_profile', '1', 5, '1'),
('ucp_request', '1', 1, '0'),
('ucp_request', '1', 2, '1'),
('ucp_request', '1', 3, '1'),
('ucp_request', '1', 4, '1'),
('ucp_request', '1', 5, '1');/*###*/

INSERT INTO {$PREFIX}config (c_id, c_value) VALUES
('auth_activate_limit', '24h'),
('auth_bind_agent', '1'),
('auth_bind_ip', '1'),
('auth_max_faillogin', '5'),
('auth_max_lifetime', '2h'),
('auth_use_reauth', '1'),
('cache_acl', '1'),
('cache_config', '1'),
('cache_main', '1'),
('cache_rss', '1'),
('cache_topic', '1'),
('cache_tpl', '1'),
('cache_user', '1'),
('cookie_domain', ''),
('cookie_path', ''),
('cookie_read_tracker', 'lb_timestamp'),
('cookie_session', 'lb_session'),
('cookie_ssl_only', '0'),
('help_class', 'direct'),
('help_mail_address', ''),
('http_detect_language', '1'),
('http_output_zlib', '0'),
('log_enable', '1'),
('log_engine', 'local'),
('log_ip', '0'),
('log_statistic', '1'),
('mail_from_mail', ''),
('mail_from_name', 'webmaster'),
('main_debug_verbose', '0'),
('main_default_group', '2'),
('main_enable', '1'),
('main_guest_uid', '1'),
('main_language', 'en'),
('main_post_edit_limit', '2h'),
('main_post_per_page', '15'),
('main_style', 'default'),
('main_tags_on_index', '50'),
('main_title', 'Larus Board'),
('main_topic_per_page', '20'),
('main_uuid', ''),
('main_version', ''),
('param_action', 'do'),
('param_ajax', 'lb_ajax_proxy.php'),
('param_file', 'lb_main.php'),
('root_path', ''),
('root_uri', ''),
('rss_limit', '20'),
('rss_payload', '1'),
('task_enable', '1'),
('uri_css', '{$ROOT_URI}/css'),
('uri_gfx', '{$ROOT_URI}/gfx'),
('uri_js', '{$ROOT_URI}/js');/*###*/

INSERT INTO {$PREFIX}config_task (ct_command, ct_time_last, ct_time_interval, ct_active) VALUES
('optimize', 0, 1209600, '1'),
('prune_user', 0, 900, '1'),
('prune_search', 0, 1800, '1'),
('prune_request', 0, 3600, '1'),
('post_timespan', 0, 86400, '1');/*###*/

INSERT INTO {$PREFIX}group (g_id, g_name, g_color, g_post_approved, g_max_post_weight, g_read_unapproved, g_post_repeat, g_executive) VALUES
(1, '{:group_alias_guest}', '000000', '1', 1, '0', '0', '0'),
(2, '{:group_alias_user}', '0000aa', '1', 1, '0', '0', '0'),
(3, '{:group_alias_mod}', '00aa00', '1', 2, '1', '0', '0'),
(4, '{:group_alias_exec}', 'aa0000', '1', 3, '1', '1', '1'),
(5, '{:group_alias_root}', 'aa00aa', '1', 3, '1', '1', '1');/*###*/

INSERT INTO {$PREFIX}post_prefix (pp_id, pp_name,pp_preset_acl,pp_list_as_request) VALUES
(1, '{:prefix_support_request}','{$MODERATOR},{$EXECUTIVE},{$OWNER}','1'),
(2, '{:prefix_staff_only}','{$MODERATOR},{$EXECUTIVE}','0'),
(3, '{:prefix_moderator_only}','{$MODERATOR}','1'),
(4, '{:prefix_executive_only}','{$EXECUTIVE}','1'),
(5, '{:prefix_announcement}','','0');/*###*/

==> larus_board-0.9.0.tbz: larus_board-0.9.0/setup/data_init.sql <==
INSERT INTO {$PREFIX}acl (a_action, a_use_group, a_key, a_allow) VALUES
('acp_acl_delete', '1', 1, '0'),
('acp_acl_delete', '1', 2, '0'),
('acp_acl_delete', '1', 3, '0'),
('acp_acl_delete', '1', 4, '1'),
('acp_acl_delete', '1', 5, '1'),
('acp_acl_edit', '1', 1, '0'),
('acp_acl_edit', '1', 2, '0'),
('acp_acl_edit', '1', 3, '0'),
('acp_acl_edit', '1', 4, '1'),
('acp_acl_edit', '1', 5, '1'),
('acp_acl_list', '1', 1, '0'),
('acp_acl_list', '1', 2, '0'),
('acp_acl_list', '1', 3, '0'),
('acp_acl_list', '1', 4, '1'),
('acp_acl_list', '1', 5, '1'),
('acp_acl_new', '1', 1, '0'),
('acp_acl_new', '1', 2, '0'),
('acp_acl_new', '1', 3, '0'),
('acp_acl_new', '1', 4, '1'),
('acp_acl_new', '1', 5, '1'),
('acp_cfg_edit', '1', 1, '0'),
('acp_cfg_edit', '1', 2, '0'),
('acp_cfg_edit', '1', 3, '0'),
('acp_cfg_edit', '1', 4, '1'),
('acp_cfg_edit', '1', 5, '1'),
('acp_cfg_list', '1', 1, '0'),
('acp_cfg_list', '1', 2, '0'),
('acp_cfg_list', '1', 3, '0'),
('acp_cfg_list', '1', 4, '1'),
('acp_cfg_list', '1', 5, '1'),
('acp_group_delete', '1', 1, '0'),
('acp_group_delete', '1', 2, '0'),
('acp_group_delete', '1', 3, '0'),
('acp_group_delete', '1', 4, '1'),
('acp_group_delete', '1', 5, '1'),
('acp_group_edit', '1', 1, '0'),
('acp_group_edit', '1', 2, '0'),
('acp_group_edit', '1', 3, '0'),
('acp_group_edit', '1', 4, '1'),
('acp_group_edit', '1', 5, '1'),
('acp_group_list', '1', 1, '0'),
('acp_group_list', '1', 2, '0'),
('acp_group_list', '1', 3, '0'),
('acp_group_list', '1', 4, '1'),
('acp_group_list', '1', 5, '1'),
('acp_group_new', '1', 1, '0'),
('acp_group_new', '1', 2, '0'),
('acp_group_new', '1', 3, '0'),
('acp_group_new', '1', 4, '1'),
('acp_group_new', '1', 5, '1'),
('acp_log', '1', 1, '0'),
('acp_log', '1', 2, '0'),
('acp_log', '1', 3, '0'),
('acp_log', '1', 4, '1'),
('acp_log', '1', 5, '1'),
('acp_overview', '1', 1, '0'),
('acp_overview', '1', 2, '0'),
('acp_overview', '1', 3, '0'),
('acp_overview', '1', 4, '1'),
('acp_overview', '1', 5, '1'),
('acp_pp_delete', '1', 1, '0'),
('acp_pp_delete', '1', 2, '0'),
('acp_pp_delete', '1', 3, '0'),
('acp_pp_delete', '1', 4, '1'),
('acp_pp_delete', '1', 5, '1'),
('acp_pp_edit', '1', 1, '0'),
('acp_pp_edit', '1', 2, '0'),
('acp_pp_edit', '1', 3, '0'),
('acp_pp_edit', '1', 4, '1'),
('acp_pp_edit', '1', 5, '1'),
('acp_pp_list', '1', 1, '0'),
('acp_pp_list', '1', 2, '0'),
('acp_pp_list', '1', 3, '0'),
('acp_pp_list', '1', 4, '1'),
('acp_pp_list', '1', 5, '1'),
('acp_pp_new', '1', 1, '0'),
('acp_pp_new', '1', 2, '0'),
('acp_pp_new', '1', 3, '0'),
('acp_pp_new', '1', 4, '1'),
('acp_pp_new', '1', 5, '1'),
('acp_task_edit', '1', 1, '0'),
('acp_task_edit', '1', 2, '0'),
('acp_task_edit', '1', 3, '0'),
('acp_task_edit', '1', 4, '1'),
('acp_task_edit', '1', 5, '1'),
('acp_task_list', '1', 1, '0'),
('acp_task_list', '1', 2, '0'),
('acp_task_list', '1', 3, '0'),
('acp_task_list', '1', 4, '1'),
('acp_task_list', '1', 5, '1'),
('cachemgr', '1', 1, '0'),
('cachemgr', '1', 2, '0'),
('cachemgr', '1', 3, '1'),
('cachemgr', '1', 4, '1'),
('cachemgr', '1', 5, '1'),
('forgot_password', '1', 1, '1'),
('forgot_password', '1', 2, '0'),
('forgot_password', '1', 3, '0'),
('forgot_password', '1', 4, '0'),
('forgot_password', '1', 5, '0'),
('help', '1', 1, '1'),
('help', '1', 2, '1'),
('help', '1', 3, '1'),
('help', '1', 4, '1'),
('help', '1', 5, '1'),
('login', '1', 1, '1'),
('login', '1', 2, '0'),
('login', '1', 3, '0'),
('login', '1', 4, '0'),
('login', '1', 5, '0'),
('logout', '1', 1, '0'),
('logout', '1', 2, '1'),
('logout', '1', 3, '1'),
('logout', '1', 4, '1'),
('logout', '1', 5, '1'),
('mcp_overview', '1', 1, '0'),
('mcp_overview', '1', 2, '0'),
('mcp_overview', '1', 3, '1'),
('mcp_overview', '1', 4, '0'),
('mcp_overview', '1', 5, '1'),
('mcp_request', '1', 1, '0'),
('mcp_request', '1', 2, '0'),
('mcp_request', '1', 3, '1'),
('mcp_request', '1', 4, '0'),
('mcp_request', '1', 5, '1'),
('member_list', '1', 1, '1'),
('member_list', '1', 2, '1'),
('member_list', '1', 3, '1'),
('member_list', '1', 4, '1'),
('member_list', '1', 5, '1'),
('overview', '1', 1, '1'),
('overview', '1', 2, '1'),
('overview', '1', 3, '1'),
('overview', '1', 4, '1'),
('overview', '1', 5, '1'),
('post_approve', '1', 1, '0'),
('post_approve', '1', 2, '0'),
('post_approve', '1', 3, '1'),
('post_approve', '1', 4, '0'),
('post_approve', '1', 5, '1'),
('post_delete', '1', 1, '0'),
('post_delete', '1', 2, '0'),
('post_delete', '1', 3, '1'),
('post_delete', '1', 4, '0'),
('post_delete', '1', 5, '1'),
('post_edit', '1', 1, '0'),
('post_edit', '1', 2, '1'),
('post_edit', '1', 3, '1'),
('post_edit', '1', 4, '1'),
('post_edit', '1', 5, '1'),
('post_edit_revert', '1', 1, '0'),
('post_edit_revert', '1', 2, '0'),
('post_edit_revert', '1', 3, '1'),
('post_edit_revert', '1', 4, '0'),
('post_edit_revert', '1', 5, '1'),
('post_lock', '1', 1, '0'),
('post_lock', '1', 2, '0'),
('post_lock', '1', 3, '1'),
('post_lock', '1', 4, '0'),
('post_lock', '1', 5, '1'),
('post_rate', '1', 1, '0'),
('post_rate', '1', 2, '1'),
('post_rate', '1', 3, '1'),
('post_rate', '1', 4, '1'),
('post_rate', '1', 5, '1'),
('post_reply', '1', 1, '0'),
('post_reply', '1', 2, '1'),
('post_reply', '1', 3, '1'),
('post_reply', '1', 4, '1'),
('post_reply', '1', 5, '1'),
('post_topic', '1', 1, '0'),
('post_topic', '1', 2, '1'),
('post_topic', '1', 3, '1'),
('post_topic', '1', 4, '1'),
('post_topic', '1', 5, '1'),
('reauth', '1', 1, '0'),
('reauth', '1', 2, '1'),
('reauth', '1', 3, '1'),
('reauth', '1', 4, '1'),
('reauth', '1', 5, '1'),
('register', '1', 1, '1'),
('register', '1', 2, '0'),
('register', '1', 3, '0'),
('register', '1', 4, '0'),
('register', '1', 5, '0'),
('rss', '1', 1, '1'),
('rss', '1', 2, '1'),
('rss', '1', 3, '1'),
('rss', '1', 4, '1'),
('rss', '1', 5, '1'),
('search', '1', 1, '1'),
('search', '1', 2, '1'),
('search', '1', 3, '1'),
('search', '1', 4, '1'),
('search', '1', 5, '1'),
('topic', '1', 1, '1'),
('topic', '1', 2, '1'),
('topic', '1', 3, '1'),
('topic', '1', 4, '1'),
('topic', '1', 5, '1'),
('ucp_blacklist', '1', 1, '0'),
('ucp_blacklist', '1', 2, '1'),
('ucp_blacklist', '1', 3, '1'),
('ucp_blacklist', '1', 4, '1'),
('ucp_blacklist', '1', 5, '1'),
('ucp_bookmark', '1', 1, '0'),
('ucp_bookmark', '1', 2, '1'),
('ucp_bookmark', '1', 3, '1'),
('ucp_bookmark', '1', 4, '1'),
('ucp_bookmark', '1', 5, '1'),
('ucp_profile', '1', 1, '0'),
('ucp_profile', '1', 2, '1'),
('ucp_profile', '1', 3, '1'),
('ucp_profile', '1', 4, '1'),
('ucp_profile', '1', 5, '1'),
('ucp_request', '1', 1, '0'),
('ucp_request', '1', 2, '1'),
('ucp_request', '1', 3, '1'),
('ucp_request', '1', 4, '1'),
('ucp_request', '1', 5, '1');/*###*/

INSERT INTO {$PREFIX}config (c_id, c_value) VALUES
('auth_activate_limit', '24h'),
('auth_bind_agent', '1'),
('auth_bind_ip', '1'),
('auth_max_faillogin', '5'),
('auth_max_lifetime', '2h'),
('auth_use_reauth', '1'),
('cache_acl', '1'),
('cache_config', '1'),
('cache_main', '1'),
('cache_rss', '1'),
('cache_topic', '1'),
('cache_tpl', '1'),
('cache_user', '1'),
('cookie_domain', ''),
('cookie_path', ''),
('cookie_read_tracker', 'lb_timestamp'),
('cookie_session', 'lb_session'),
('cookie_ssl_only', '0'),
('help_class', 'direct'),
('help_mail_address', ''),
('http_detect_language', '1'),
('http_output_zlib', '0'),
('log_enable', '1'),
('log_engine', 'local'),
('log_ip', '0'),
('log_statistic', '1'),
('mail_from_mail', ''),
('mail_from_name', 'webmaster'),
('main_debug_verbose', '0'),
('main_default_group', '2'),
('main_enable', '1'),
('main_guest_uid', '1'),
('main_language', 'en'),
('main_post_edit_limit', '2h'),
('main_post_per_page', '15'),
('main_style', 'default'),
('main_tags_on_index', '50'),
('main_title', 'Larus Board'),
('main_topic_navbar', '1'),
('main_topic_per_page', '20'),
('main_uuid', ''),
('main_version', ''),
('param_action', 'do'),
('param_ajax', '{$ROOT_URI}/lb_ajax_proxy.php'),
('param_file', '{$ROOT_URI}/lb_main.php'),
('root_path', ''),
('root_uri', ''),
('rss_limit', '20'),
('rss_payload', '1'),
('task_enable', '1'),
('uri_css', '{$ROOT_URI}/css'),
('uri_gfx', '{$ROOT_URI}/gfx'),
('uri_js', '{$ROOT_URI}/js');/*###*/

INSERT INTO {$PREFIX}config_task (ct_command, ct_time_last, ct_time_interval, ct_active) VALUES
('optimize', 0, 1209600, '1'),
('prune_user', 0, 900, '1'),
('prune_search', 0, 1800, '1'),
('prune_request', 0, 3600, '1'),
('post_timespan', 0, 86400, '1');/*###*/

INSERT INTO {$PREFIX}group (g_id, g_name, g_color, g_post_approved, g_max_post_weight, g_read_unapproved, g_post_repeat, g_executive) VALUES
(1, '{:group_alias_guest}', '000000', '1', 1, '0', '0', '0'),
(2, '{:group_alias_user}', '0000aa', '1', 1, '0', '0', '0'),
(3, '{:group_alias_mod}', '00aa00', '1', 2, '1', '0', '0'),
(4, '{:group_alias_exec}', 'aa0000', '1', 3, '1', '1', '1'),
(5, '{:group_alias_root}', 'aa00aa', '1', 3, '1', '1', '1');/*###*/

INSERT INTO {$PREFIX}post_prefix (pp_id, pp_name,pp_preset_acl,pp_list_as_request) VALUES
(1, '{:prefix_support_request}','{$MODERATOR},{$EXECUTIVE},{$OWNER}','1'),
(2, '{:prefix_staff_only}','{$MODERATOR},{$EXECUTIVE}','0'),
(3, '{:prefix_moderator_only}','{$MODERATOR}','1'),
(4, '{:prefix_executive_only}','{$EXECUTIVE}','1'),
(5, '{:prefix_announcement}','','0');/*###*/
